Documentation
ΒΆ
Index ΒΆ
Constants ΒΆ
const Uint64Size = 8
Variables ΒΆ
This section is empty.
Functions ΒΆ
func CloneByteSlice ΒΆ
CloneByteSlice clones a slice of bytes, as slices.Clone would do, but does not allocate extra space.
func ConcatByteSlices ΒΆ
ConcatByteSlice concatenates a byte slices, as slices.Concat would do, but does not allocate extra space.
func UpdateWithTx ΒΆ
UpdateWithTx passes the dirty value to the transaction function and, if the transaction occurred without errors, replaces the target with the dirty version. This is useful for use in public methods to avoid corrupting the state with errors.
Types ΒΆ
Click to show internal directories.
Click to hide internal directories.